@@ -1,10 +1,11 @@
 from django.apps import AppConfig
-from django.utils.translation import gettext_lazy as _
 from django.utils.module_loading import autodiscover_modules
+from django.utils.translation import gettext_lazy as _
+
 
 class CmsConfig(AppConfig):
-    name = 'cms'
-    verbose_name = _('Content Management System')
+    name = "cms"
+    verbose_name = _("Content Management System")
 
     def ready(self):
-        autodiscover_modules('views')
+        autodiscover_modules("views")
